@@ -80,7 +80,6 @@ static gsize printf_string_upper_bound (const gchar *format,
 
 static GMutex* g_messages_lock = NULL;
 
-const gchar	     *g_log_domain_glib = "GLib";
 static GLogDomain    *g_log_domains = NULL;
 static GLogLevelFlags g_log_always_fatal = G_LOG_FATAL_MASK;
 static GPrintFunc     glib_print_func = NULL;
@@ -473,9 +472,12 @@ g_logv (const gchar   *log_domain,
 	const gchar   *format,
 	va_list	       args1)
 {
-  va_list args2;
   gchar buffer[1025];
   register gint i;
+
+#ifndef  HAVE_VSNPRINTF
+  va_list args2;
+#endif	/* HAVE_VSNPRINTF */
   
   log_level &= G_LOG_LEVEL_MASK;
   if (!log_level)
@@ -1170,7 +1172,12 @@ gsize
 g_printf_string_upper_bound (const gchar *format,
 			     va_list      args)
 {
+#if HAVE_C99_VSNPRINTF
+  gchar c;
+  return vsnprintf (&c, 1, format, args);
+#else
   return printf_string_upper_bound (format, TRUE, args);
+#endif
 }
 
 void
