@@ -341,44 +341,14 @@ g_snprintf (gchar	*str,
 	    gchar const *fmt,
 	    ...)
 {
-#ifdef	HAVE_VSNPRINTF
   va_list args;
   gint retval;
-  
-  g_return_val_if_fail (str != NULL, 0);
-  g_return_val_if_fail (n > 0, 0);
-  g_return_val_if_fail (fmt != NULL, 0);
 
   va_start (args, fmt);
-  retval = vsnprintf (str, n, fmt, args);
+  retval = g_vsnprintf (str, n, fmt, args);
   va_end (args);
-
-  if (retval < 0)
-    {
-      str[n-1] = '\0';
-      retval = strlen (str);
-    }
-
+  
   return retval;
-#else	/* !HAVE_VSNPRINTF */
-  gchar *printed;
-  va_list args;
-  
-  g_return_val_if_fail (str != NULL, 0);
-  g_return_val_if_fail (n > 0, 0);
-  g_return_val_if_fail (fmt != NULL, 0);
-
-  va_start (args, fmt);
-  printed = g_strdup_vprintf (fmt, args);
-  va_end (args);
-  
-  strncpy (str, printed, n);
-  str[n-1] = '\0';
-
-  g_free (printed);
-  
-  return strlen (str);
-#endif	/* !HAVE_VSNPRINTF */
 }
 
 gint
@@ -387,37 +357,30 @@ g_vsnprintf (gchar	 *str,
 	     gchar const *fmt,
 	     va_list      args)
 {
-#ifdef	HAVE_VSNPRINTF
-  gint retval;
-  
-  g_return_val_if_fail (str != NULL, 0);
-  g_return_val_if_fail (n > 0, 0);
+#ifdef	HAVE_VSNPRINTF_C99
+  g_return_val_if_fail (n == 0 || str != NULL, 0);
   g_return_val_if_fail (fmt != NULL, 0);
 
-  retval = vsnprintf (str, n, fmt, args);
-  
-  if (retval < 0)
-    {
-      str[n-1] = '\0';
-      retval = strlen (str);
-    }
-
-  return retval;
-#else	/* !HAVE_VSNPRINTF */
+  return vsnprintf (str, n, fmt, args);
+#else	/* !HAVE_VSNPRINTF_C99 */
   gchar *printed;
-  
-  g_return_val_if_fail (str != NULL, 0);
-  g_return_val_if_fail (n > 0, 0);
+  gint retval;
+
+  g_return_val_if_fail (n == 0 || str != NULL, 0);
   g_return_val_if_fail (fmt != NULL, 0);
 
   printed = g_strdup_vprintf (fmt, args);
-  strncpy (str, printed, n);
-  str[n-1] = '\0';
+  retval = strlen (printed);
+  if (n > 0)
+    {
+      strncpy (str, printed, n - 1);
+      str[n-1] = '\0';
+    }
 
   g_free (printed);
   
-  return strlen (str);
-#endif /* !HAVE_VSNPRINTF */
+  return retval;
+#endif /* !HAVE_VSNPRINTF_C99 */
 }
 
 guint	     
@@ -1000,6 +963,7 @@ g_get_tmp_dir (void)
   return g_tmp_dir;
 }
 
+G_LOCK_DEFINE (g_prgname);
 static gchar *g_prgname = NULL;
 
 gchar*
@@ -1007,9 +971,9 @@ g_get_prgname (void)
 {
   gchar* retval;
 
-  G_LOCK (g_utils_global);
+  G_LOCK (g_prgname);
   retval = g_prgname;
-  G_UNLOCK (g_utils_global);
+  G_UNLOCK (g_prgname);
 
   return retval;
 }
@@ -1017,13 +981,10 @@ g_get_prgname (void)
 void
 g_set_prgname (const gchar *prgname)
 {
-  gchar *c;
-    
-  G_LOCK (g_utils_global);
-  c = g_prgname;
+  G_LOCK (g_prgname);
+  g_free (g_prgname);
   g_prgname = g_strdup (prgname);
-  g_free (c);
-  G_UNLOCK (g_utils_global);
+  G_UNLOCK (g_prgname);
 }
 
 guint
@@ -1095,24 +1056,25 @@ g_get_codeset (void)
 
 #include <libintl.h>
 
+#ifdef G_PLATFORM_WIN32
 
-#ifdef G_OS_WIN32
+G_WIN32_DLLMAIN_FOR_DLL_NAME (static, dll_name)
 
-/* On Windows we don't want any hard-coded path names */
+static const gchar *
+_glib_get_locale_dir (void)
+{
+  static const gchar *cache = NULL;
+  if (cache == NULL)
+    cache = g_win32_get_package_installation_subdirectory
+      (GETTEXT_PACKAGE, dll_name, "lib\\locale");
+
+  return cache;
+}
 
 #undef GLIB_LOCALE_DIR
-/* It's OK to leak the g_win32_get_...() and g_strdup_printf() results
- * below, as this macro is called only once. */
-#define GLIB_LOCALE_DIR					      	\
-  g_win32_get_package_installation_subdirectory			\
-  (GETTEXT_PACKAGE,						\
-   g_strdup_printf ("libglib-%d.%d-%d.dll",			\
-		    GLIB_MAJOR_VERSION,				\
-		    GLIB_MINOR_VERSION,				\
-		    GLIB_MICRO_VERSION - GLIB_BINARY_AGE),	\
-   "share\\locale")
+#define GLIB_LOCALE_DIR _glib_get_locale_dir ()
 
-#endif /* !G_OS_WIN32 */
+#endif /* G_PLATFORM_WIN32 */
 
 G_CONST_RETURN gchar *
 _glib_gettext (const gchar *str)
@@ -1129,5 +1091,3 @@ _glib_gettext (const gchar *str)
 }
 
 #endif /* ENABLE_NLS */
-
-
