@@ -773,45 +773,6 @@ param_pointer_values_cmp (GParamSpec   *pspec,
   return p1 < p2 ? -1 : p1 > p2;
 }
 
-static void
-param_closure_init (GParamSpec *pspec)
-{
-  /* GParamSpecClosure *cspec = G_PARAM_SPEC_CLOSURE (pspec); */
-}
-
-static void
-param_closure_set_default (GParamSpec *pspec,
-			   GValue     *value)
-{
-  value->data[0].v_pointer = NULL;
-}
-
-static gboolean
-param_closure_validate (GParamSpec *pspec,
-			GValue     *value)
-{
-  /* GParamSpecClosure *cspec = G_PARAM_SPEC_CLOSURE (pspec); */
-  /* GClosure *closure = value->data[0].v_pointer; */
-  guint changed = 0;
-
-  /* we don't actually have necessary means to ensure closure validity */
-
-  return changed;
-}
-
-static gint
-param_closure_values_cmp (GParamSpec   *pspec,
-			  const GValue *value1,
-			  const GValue *value2)
-{
-  guint8 *p1 = value1->data[0].v_pointer;
-  guint8 *p2 = value2->data[0].v_pointer;
-
-  /* not much to compare here, try to at least provide stable lesser/greater result */
-
-  return p1 < p2 ? -1 : p1 > p2;
-}
-
 static void
 param_value_array_init (GParamSpec *pspec)
 {
@@ -998,10 +959,17 @@ param_object_values_cmp (GParamSpec   *pspec,
 
 
 /* --- type initialization --- */
+GType *g_param_spec_types = NULL;
+
 void
 g_param_spec_types_init (void)	/* sync with gtype.c */
 {
-  GType type;
+  const guint n_types = 20;
+  GType type, *spec_types, *spec_types_bound;
+
+  g_param_spec_types = g_new0 (GType, n_types);
+  spec_types = g_param_spec_types;
+  spec_types_bound = g_param_spec_types + n_types;
   
   /* G_TYPE_PARAM_CHAR
    */
@@ -1017,6 +985,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_int_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamChar", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_CHAR);
   }
   
@@ -1034,6 +1003,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_uint_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamUChar", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UCHAR);
   }
   
@@ -1051,6 +1021,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_int_values_cmp,       /* values_cmp */
     };
     type = g_param_type_register_static ("GParamBoolean", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_BOOLEAN);
   }
   
@@ -1068,6 +1039,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_int_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamInt", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_INT);
   }
   
@@ -1085,6 +1057,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_uint_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamUInt", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UINT);
   }
   
@@ -1102,6 +1075,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_long_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamLong", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_LONG);
   }
   
@@ -1119,6 +1093,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_ulong_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamULong", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_ULONG);
   }
 
@@ -1136,6 +1111,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_int64_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamInt64", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_INT64);
   }
   
@@ -1153,6 +1129,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_uint64_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamUInt64", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UINT64);
   }
 
@@ -1170,6 +1147,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_unichar_values_cmp,	 /* values_cmp */
     };
     type = g_param_type_register_static ("GParamUnichar", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UNICHAR);
   }
 
@@ -1187,6 +1165,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_long_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamEnum", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_ENUM);
   }
   
@@ -1204,6 +1183,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_ulong_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamFlags", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_FLAGS);
   }
   
@@ -1221,6 +1201,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_float_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamFloat", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_FLOAT);
   }
   
@@ -1238,6 +1219,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_double_values_cmp,		/* values_cmp */
     };
     type = g_param_type_register_static ("GParamDouble", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_DOUBLE);
   }
   
@@ -1255,6 +1237,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_string_values_cmp,		/* values_cmp */
     };
     type = g_param_type_register_static ("GParamString", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_STRING);
   }
   
@@ -1272,6 +1255,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_pointer_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamParam", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_PARAM);
   }
   
@@ -1289,6 +1273,7 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_boxed_values_cmp,	/* values_cmp */
     };
     type = g_param_type_register_static ("GParamBoxed", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_BOXED);
   }
 
@@ -1306,43 +1291,29 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_pointer_values_cmp,	   /* values_cmp */
     };
     type = g_param_type_register_static ("GParamPointer", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_POINTER);
   }
   
   /* G_TYPE_PARAM_VALUE_ARRAY
    */
   {
-    static const GParamSpecTypeInfo pspec_info = {
+    static /* const */ GParamSpecTypeInfo pspec_info = {
       sizeof (GParamSpecValueArray),	/* instance_size */
       0,				/* n_preallocs */
       param_value_array_init,		/* instance_init */
-      G_TYPE_VALUE_ARRAY,		/* value_type */
+      0xdeadbeef,			/* value_type, assigned further down */
       param_value_array_finalize,	/* finalize */
       param_value_array_set_default,	/* value_set_default */
       param_value_array_validate,	/* value_validate */
       param_value_array_values_cmp,	/* values_cmp */
     };
+    pspec_info.value_type = G_TYPE_VALUE_ARRAY;
     type = g_param_type_register_static ("GParamValueArray", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_VALUE_ARRAY);
   }
 
-  /* G_TYPE_PARAM_CLOSURE
-   */
-  {
-    static const GParamSpecTypeInfo pspec_info = {
-      sizeof (GParamSpecClosure),   /* instance_size */
-      0,                            /* n_preallocs */
-      param_closure_init,	    /* instance_init */
-      G_TYPE_CLOSURE,		    /* value_type */
-      NULL,			    /* finalize */
-      param_closure_set_default,    /* value_set_default */
-      param_closure_validate,	    /* value_validate */
-      param_closure_values_cmp,     /* values_cmp */
-    };
-    type = g_param_type_register_static ("GParamClosure", &pspec_info);
-    g_assert (type == G_TYPE_PARAM_CLOSURE);
-  }
-  
   /* G_TYPE_PARAM_OBJECT
    */
   {
@@ -1357,8 +1328,11 @@ g_param_spec_types_init (void)	/* sync with gtype.c */
       param_object_values_cmp,	 /* values_cmp */
     };
     type = g_param_type_register_static ("GParamObject", &pspec_info);
+    *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_OBJECT);
   }
+
+  g_assert (spec_types == spec_types_bound);
 }
 
 
@@ -1828,22 +1802,6 @@ g_param_spec_value_array (const gchar *name,
   return G_PARAM_SPEC (aspec);
 }
 
-GParamSpec*
-g_param_spec_closure (const gchar *name,
-		      const gchar *nick,
-		      const gchar *blurb,
-		      GParamFlags  flags)
-{
-  GParamSpecClosure *cspec;
-  
-  cspec = g_param_spec_internal (G_TYPE_PARAM_CLOSURE,
-				 name,
-				 nick,
-				 blurb,
-				 flags);
-  return G_PARAM_SPEC (cspec);
-}
-
 GParamSpec*
 g_param_spec_object (const gchar *name,
 		     const gchar *nick,
