@@ -152,6 +152,7 @@ gboolean	      g_signal_parse_name   (const gchar	*detailed_signal,
 					     guint		*signal_id_p,
 					     GQuark		*detail_p,
 					     gboolean		 force_detail_quark);
+GSignalInvocationHint* g_signal_get_invocation_hint (gpointer    instance);
 
 
 /* --- signal emissions --- */
@@ -232,13 +233,12 @@ void	g_signal_override_class_closure	      (guint		  signal_id,
 					       GType		  instance_type,
 					       GClosure		 *class_closure);
 void	g_signal_chain_from_overridden	      (const GValue      *instance_and_params,
-					       guint              signal_id,
 					       GValue            *return_value);
 
 
 /* --- convenience --- */
 #define g_signal_connect(instance, detailed_signal, c_handler, data) \
-    g_signal_connect_data ((instance), (detailed_signal), (c_handler), (data), NULL, 0)
+    g_signal_connect_data ((instance), (detailed_signal), (c_handler), (data), NULL, (GConnectFlags) 0)
 #define g_signal_connect_after(instance, detailed_signal, c_handler, data) \
     g_signal_connect_data ((instance), (detailed_signal), (c_handler), (data), NULL, G_CONNECT_AFTER)
 #define g_signal_connect_swapped(instance, detailed_signal, c_handler, data) \
